/*
 Copyright 2016 Goldman Sachs.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 */

package com.gs.fw.common.mithra.connectionmanager;


import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.*;
import java.util.Calendar;
import java.util.Map;

public class DelegatingCallableStatement extends DelegatingPreparedStatement implements CallableStatement
{
    public DelegatingCallableStatement(PreparedStatement delegate)
    {
        super(delegate);
    }

    protected CallableStatement getDelegate()
    {
        return (CallableStatement) super.getDelegate();
    }

    @Override
    public Array getArray(int parameterIndex) throws SQLException
    {
        return getDelegate().getArray(parameterIndex);
    }

    @Override
    public Array getArray(String parameterName) throws SQLException
    {
        return getDelegate().getArray(parameterName);
    }

    @Override
    public BigDecimal getBigDecimal(int parameterIndex) throws SQLException
    {
        return getDelegate().getBigDecimal(parameterIndex);
    }

    @Override
    public BigDecimal getBigDecimal(int parameterIndex, int scale) throws SQLException
    {
        return getDelegate().getBigDecimal(parameterIndex, scale);
    }

    @Override
    public BigDecimal getBigDecimal(String parameterName) throws SQLException
    {
        return getDelegate().getBigDecimal(parameterName);
    }

    @Override
    public Blob getBlob(int parameterIndex) throws SQLException
    {
        return getDelegate().getBlob(parameterIndex);
    }

    @Override
    public Blob getBlob(String parameterName) throws SQLException
    {
        return getDelegate().getBlob(parameterName);
    }

    @Override
    public boolean getBoolean(int parameterIndex) throws SQLException
    {
        return getDelegate().getBoolean(parameterIndex);
    }

    @Override
    public boolean getBoolean(String parameterName) throws SQLException
    {
        return getDelegate().getBoolean(parameterName);
    }

    @Override
    public byte getByte(int parameterIndex) throws SQLException
    {
        return getDelegate().getByte(parameterIndex);
    }

    @Override
    public byte getByte(String parameterName) throws SQLException
    {
        return getDelegate().getByte(parameterName);
    }

    @Override
    public byte[] getBytes(int parameterIndex) throws SQLException
    {
        return getDelegate().getBytes(parameterIndex);
    }

    @Override
    public byte[] getBytes(String parameterName) throws SQLException
    {
        return getDelegate().getBytes(parameterName);
    }

    @Override
    public Reader getCharacterStream(int parameterIndex) throws SQLException
    {
        return getDelegate().getCharacterStream(parameterIndex);
    }

    @Override
    public Reader getCharacterStream(String parameterName) throws SQLException
    {
        return getDelegate().getCharacterStream(parameterName);
    }

    @Override
    public Clob getClob(int parameterIndex) throws SQLException
    {
        return getDelegate().getClob(parameterIndex);
    }

    @Override
    public Clob getClob(String parameterName) throws SQLException
    {
        return getDelegate().getClob(parameterName);
    }

    @Override
    public Date getDate(int parameterIndex) throws SQLException
    {
        return getDelegate().getDate(parameterIndex);
    }

    @Override
    public Date getDate(int parameterIndex, Calendar cal) throws SQLException
    {
        return getDelegate().getDate(parameterIndex, cal);
    }

    @Override
    public Date getDate(String parameterName) throws SQLException
    {
        return getDelegate().getDate(parameterName);
    }

    @Override
    public Date getDate(String parameterName, Calendar cal) throws SQLException
    {
        return getDelegate().getDate(parameterName, cal);
    }

    @Override
    public double getDouble(int parameterIndex) throws SQLException
    {
        return getDelegate().getDouble(parameterIndex);
    }

    @Override
    public double getDouble(String parameterName) throws SQLException
    {
        return getDelegate().getDouble(parameterName);
    }

    @Override
    public float getFloat(int parameterIndex) throws SQLException
    {
        return getDelegate().getFloat(parameterIndex);
    }

    @Override
    public float getFloat(String parameterName) throws SQLException
    {
        return getDelegate().getFloat(parameterName);
    }

    @Override
    public int getInt(int parameterIndex) throws SQLException
    {
        return getDelegate().getInt(parameterIndex);
    }

    @Override
    public int getInt(String parameterName) throws SQLException
    {
        return getDelegate().getInt(parameterName);
    }

    @Override
    public long getLong(int parameterIndex) throws SQLException
    {
        return getDelegate().getLong(parameterIndex);
    }

    @Override
    public long getLong(String parameterName) throws SQLException
    {
        return getDelegate().getLong(parameterName);
    }

    @Override
    public Reader getNCharacterStream(int parameterIndex) throws SQLException
    {
        return getDelegate().getNCharacterStream(parameterIndex);
    }

    @Override
    public Reader getNCharacterStream(String parameterName) throws SQLException
    {
        return getDelegate().getNCharacterStream(parameterName);
    }

    @Override
    public NClob getNClob(int parameterIndex) throws SQLException
    {
        return getDelegate().getNClob(parameterIndex);
    }

    @Override
    public NClob getNClob(String parameterName) throws SQLException
    {
        return getDelegate().getNClob(parameterName);
    }

    @Override
    public String getNString(int parameterIndex) throws SQLException
    {
        return getDelegate().getNString(parameterIndex);
    }

    @Override
    public String getNString(String parameterName) throws SQLException
    {
        return getDelegate().getNString(parameterName);
    }

    @Override
    public Object getObject(int parameterIndex) throws SQLException
    {
        return getDelegate().getObject(parameterIndex);
    }

    @Override
    public Object getObject(int parameterIndex, Map<String, Class<?>> map) throws SQLException
    {
        return getDelegate().getObject(parameterIndex, map);
    }

    @Override
    public Object getObject(String parameterName) throws SQLException
    {
        return getDelegate().getObject(parameterName);
    }

    @Override
    public Object getObject(String parameterName, Map<String, Class<?>> map) throws SQLException
    {
        return getDelegate().getObject(parameterName, map);
    }

    @Override
    public Ref getRef(int parameterIndex) throws SQLException
    {
        return getDelegate().getRef(parameterIndex);
    }

    @Override
    public Ref getRef(String parameterName) throws SQLException
    {
        return getDelegate().getRef(parameterName);
    }

    @Override
    public RowId getRowId(int parameterIndex) throws SQLException
    {
        return getDelegate().getRowId(parameterIndex);
    }

    @Override
    public RowId getRowId(String parameterName) throws SQLException
    {
        return getDelegate().getRowId(parameterName);
    }

    @Override
    public short getShort(int parameterIndex) throws SQLException
    {
        return getDelegate().getShort(parameterIndex);
    }

    @Override
    public short getShort(String parameterName) throws SQLException
    {
        return getDelegate().getShort(parameterName);
    }

    @Override
    public SQLXML getSQLXML(int parameterIndex) throws SQLException
    {
        return getDelegate().getSQLXML(parameterIndex);
    }

    @Override
    public SQLXML getSQLXML(String parameterName) throws SQLException
    {
        return getDelegate().getSQLXML(parameterName);
    }

    @Override
    public String getString(int parameterIndex) throws SQLException
    {
        return getDelegate().getString(parameterIndex);
    }

    @Override
    public String getString(String parameterName) throws SQLException
    {
        return getDelegate().getString(parameterName);
    }

    @Override
    public Time getTime(int parameterIndex) throws SQLException
    {
        return getDelegate().getTime(parameterIndex);
    }

    @Override
    public Time getTime(int parameterIndex, Calendar cal) throws SQLException
    {
        return getDelegate().getTime(parameterIndex, cal);
    }

    @Override
    public Time getTime(String parameterName) throws SQLException
    {
        return getDelegate().getTime(parameterName);
    }

    @Override
    public Time getTime(String parameterName, Calendar cal) throws SQLException
    {
        return getDelegate().getTime(parameterName, cal);
    }

    @Override
    public Timestamp getTimestamp(int parameterIndex) throws SQLException
    {
        return getDelegate().getTimestamp(parameterIndex);
    }

    @Override
    public Timestamp getTimestamp(int parameterIndex, Calendar cal) throws SQLException
    {
        return getDelegate().getTimestamp(parameterIndex, cal);
    }

    @Override
    public Timestamp getTimestamp(String parameterName) throws SQLException
    {
        return getDelegate().getTimestamp(parameterName);
    }

    @Override
    public Timestamp getTimestamp(String parameterName, Calendar cal) throws SQLException
    {
        return getDelegate().getTimestamp(parameterName, cal);
    }

    @Override
    public URL getURL(int parameterIndex) throws SQLException
    {
        return getDelegate().getURL(parameterIndex);
    }

    @Override
    public URL getURL(String parameterName) throws SQLException
    {
        return getDelegate().getURL(parameterName);
    }

    @Override
    public void registerOutParameter(int parameterIndex, int sqlType) throws SQLException
    {
        getDelegate().registerOutParameter(parameterIndex, sqlType);
    }

    @Override
    public void registerOutParameter(int parameterIndex, int sqlType, int scale) throws SQLException
    {
        getDelegate().registerOutParameter(parameterIndex, sqlType, scale);
    }

    @Override
    public void registerOutParameter(int parameterIndex, int sqlType, String typeName) throws SQLException
    {
        getDelegate().registerOutParameter(parameterIndex, sqlType, typeName);
    }

    @Override
    public void registerOutParameter(String parameterName, int sqlType) throws SQLException
    {
        getDelegate().registerOutParameter(parameterName, sqlType);
    }

    @Override
    public void registerOutParameter(String parameterName, int sqlType, int scale) throws SQLException
    {
        getDelegate().registerOutParameter(parameterName, sqlType, scale);
    }

    @Override
    public void registerOutParameter(String parameterName, int sqlType, String typeName) throws SQLException
    {
        getDelegate().registerOutParameter(parameterName, sqlType, typeName);
    }

    @Override
    public void setAsciiStream(String parameterName, InputStream x) throws SQLException
    {
        getDelegate().setAsciiStream(parameterName, x);
    }

    @Override
    public void setAsciiStream(String parameterName, InputStream x, int length) throws SQLException
    {
        getDelegate().setAsciiStream(parameterName, x, length);
    }

    @Override
    public void setAsciiStream(String parameterName, InputStream x, long length) throws SQLException
    {
        getDelegate().setAsciiStream(parameterName, x, length);
    }

    @Override
    public void setBigDecimal(String parameterName, BigDecimal x) throws SQLException
    {
        getDelegate().setBigDecimal(parameterName, x);
    }

    @Override
    public void setBinaryStream(String parameterName, InputStream x) throws SQLException
    {
        getDelegate().setBinaryStream(parameterName, x);
    }

    @Override
    public void setBinaryStream(String parameterName, InputStream x, int length) throws SQLException
    {
        getDelegate().setBinaryStream(parameterName, x, length);
    }

    @Override
    public void setBinaryStream(String parameterName, InputStream x, long length) throws SQLException
    {
        getDelegate().setBinaryStream(parameterName, x, length);
    }

    @Override
    public void setBlob(String parameterName, InputStream inputStream) throws SQLException
    {
        getDelegate().setBlob(parameterName, inputStream);
    }

    @Override
    public void setBlob(String parameterName, InputStream inputStream, long length) throws SQLException
    {
        getDelegate().setBlob(parameterName, inputStream, length);
    }

    @Override
    public void setBlob(String parameterName, Blob x) throws SQLException
    {
        getDelegate().setBlob(parameterName, x);
    }

    @Override
    public void setBoolean(String parameterName, boolean x) throws SQLException
    {
        getDelegate().setBoolean(parameterName, x);
    }

    @Override
    public void setByte(String parameterName, byte x) throws SQLException
    {
        getDelegate().setByte(parameterName, x);
    }

    @Override
    public void setBytes(String parameterName, byte[] x) throws SQLException
    {
        getDelegate().setBytes(parameterName, x);
    }

    @Override
    public void setCharacterStream(String parameterName, Reader reader) throws SQLException
    {
        getDelegate().setCharacterStream(parameterName, reader);
    }

    @Override
    public void setCharacterStream(String parameterName, Reader reader, int length) throws SQLException
    {
        getDelegate().setCharacterStream(parameterName, reader, length);
    }

    @Override
    public void setCharacterStream(String parameterName, Reader reader, long length) throws SQLException
    {
        getDelegate().setCharacterStream(parameterName, reader, length);
    }

    @Override
    public void setClob(String parameterName, Reader reader) throws SQLException
    {
        getDelegate().setClob(parameterName, reader);
    }

    @Override
    public void setClob(String parameterName, Reader reader, long length) throws SQLException
    {
        getDelegate().setClob(parameterName, reader, length);
    }

    @Override
    public void setClob(String parameterName, Clob x) throws SQLException
    {
        getDelegate().setClob(parameterName, x);
    }

    @Override
    public void setDate(String parameterName, Date x) throws SQLException
    {
        getDelegate().setDate(parameterName, x);
    }

    @Override
    public void setDate(String parameterName, Date x, Calendar cal) throws SQLException
    {
        getDelegate().setDate(parameterName, x, cal);
    }

    @Override
    public void setDouble(String parameterName, double x) throws SQLException
    {
        getDelegate().setDouble(parameterName, x);
    }

    @Override
    public void setFloat(String parameterName, float x) throws SQLException
    {
        getDelegate().setFloat(parameterName, x);
    }

    @Override
    public void setInt(String parameterName, int x) throws SQLException
    {
        getDelegate().setInt(parameterName, x);
    }

    @Override
    public void setLong(String parameterName, long x) throws SQLException
    {
        getDelegate().setLong(parameterName, x);
    }

    @Override
    public void setNCharacterStream(String parameterName, Reader value) throws SQLException
    {
        getDelegate().setNCharacterStream(parameterName, value);
    }

    @Override
    public void setNCharacterStream(String parameterName, Reader value, long length) throws SQLException
    {
        getDelegate().setNCharacterStream(parameterName, value, length);
    }

    @Override
    public void setNClob(String parameterName, Reader reader) throws SQLException
    {
        getDelegate().setNClob(parameterName, reader);
    }

    @Override
    public void setNClob(String parameterName, Reader reader, long length) throws SQLException
    {
        getDelegate().setNClob(parameterName, reader, length);
    }

    @Override
    public void setNClob(String parameterName, NClob value) throws SQLException
    {
        getDelegate().setNClob(parameterName, value);
    }

    @Override
    public void setNString(String parameterName, String value) throws SQLException
    {
        getDelegate().setNString(parameterName, value);
    }

    @Override
    public void setNull(String parameterName, int sqlType) throws SQLException
    {
        getDelegate().setNull(parameterName, sqlType);
    }

    @Override
    public void setNull(String parameterName, int sqlType, String typeName) throws SQLException
    {
        getDelegate().setNull(parameterName, sqlType, typeName);
    }

    @Override
    public void setObject(String parameterName, Object x) throws SQLException
    {
        getDelegate().setObject(parameterName, x);
    }

    @Override
    public void setObject(String parameterName, Object x, int targetSqlType) throws SQLException
    {
        getDelegate().setObject(parameterName, x, targetSqlType);
    }

    @Override
    public void setObject(String parameterName, Object x, int targetSqlType, int scale) throws SQLException
    {
        getDelegate().setObject(parameterName, x, targetSqlType, scale);
    }

    @Override
    public void setRowId(String parameterName, RowId x) throws SQLException
    {
        getDelegate().setRowId(parameterName, x);
    }

    @Override
    public void setShort(String parameterName, short x) throws SQLException
    {
        getDelegate().setShort(parameterName, x);
    }

    @Override
    public void setSQLXML(String parameterName, SQLXML xmlObject) throws SQLException
    {
        getDelegate().setSQLXML(parameterName, xmlObject);
    }

    @Override
    public void setString(String parameterName, String x) throws SQLException
    {
        getDelegate().setString(parameterName, x);
    }

    @Override
    public void setTime(String parameterName, Time x) throws SQLException
    {
        getDelegate().setTime(parameterName, x);
    }

    @Override
    public void setTime(String parameterName, Time x, Calendar cal) throws SQLException
    {
        getDelegate().setTime(parameterName, x, cal);
    }

    @Override
    public void setTimestamp(String parameterName, Timestamp x) throws SQLException
    {
        getDelegate().setTimestamp(parameterName, x);
    }

    @Override
    public void setTimestamp(String parameterName, Timestamp x, Calendar cal) throws SQLException
    {
        getDelegate().setTimestamp(parameterName, x, cal);
    }

    @Override
    public void setURL(String parameterName, URL val) throws SQLException
    {
        getDelegate().setURL(parameterName, val);
    }

    @Override
    public boolean wasNull() throws SQLException
    {
        return getDelegate().wasNull();
    }
}
